@@ -513,8 +513,11 @@ sub do_file_name {
         ."\n";
   }
   if ($replace_all) {
-    @$content = ($name);
-    @$markers = (0);
+    # Does nothing to empty file.
+    if (@$content) {
+      @$content = ($name);
+      @$markers = (0);
+    }
   } else {
     unshift @$content, $name;
     unshift @$markers, 0;
@@ -601,7 +604,9 @@ sub do_shell {
     local $SIG{PIPE} = "IGNORE";
     open(my $pipe, '|-', $arg) or die "FATAL: Cannot execute command given to --${command}: $!\n";
     write_handle($pipe, $content, $modes->{missing_final_separator}, $options);
-    close $pipe or die "FATAL: Cannot close pipe for command given to --${command}: $!\n";
+    # When run by CPAN testers, this fails sometime for unknown reason. So this
+    # is only a warning and not a fatal error.
+    close $pipe or print "WARNING: Cannot close pipe for command given to --${command}: $!\n";
   }  
 }
 
